# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""multistage std cms imaging scripts

Revision ID: 09dec567edcd
Revises: ec5653e2ec49
Create Date: 2021-10-11 09:06:08.863906

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "09dec567edcd"
down_revision = "ec5653e2ec49"
branch_labels = None
depends_on = None


envoy_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR
{{#remote}}
export CAPO_PATH=.
export CAPO_PROFILE={{profile}}
{{/remote}}

./framework.sh -d .
chmod 770 .
mv {{sdmId}}.ms ./rawdata
./casa_envoy --standard-img $1 $2

"""

convey_content = """#!/bin/sh
set -o errexit

export HOME=$TMPDIR

./conveyor --deliver-img $1

"""

old_content = """#!/bin/sh

export HOME=$TMPDIR

set -o errexit
./framework.sh -d .
chmod 770 .
mv {{sdmId}}.ms ./rawdata
./casa_envoy --standard-img $1 $2
./conveyor --deliver-img $1

"""


def upgrade():
    op.execute(
        """
        DELETE FROM workflow_templates WHERE filename='std_cms_imaging.sh'
        """
    )
    op.execute(
        f"""
                INSERT INTO workflow_templates (filename, content, workflow_name)
                VALUES ('std_cms_imaging_envoy.sh', E'{envoy_content}', 'std_cms_imaging')
                """
    )
    op.execute(
        f"""
                INSERT INTO workflow_templates (filename, content, workflow_name)
                VALUES ('std_cms_imaging_convey.sh', E'{convey_content}', 'std_cms_imaging')
                """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflow_templates
        WHERE filename like ('std_cms_imaging_%.sh')
        AND workflow_name = 'std_cms_imaging'
        """
    )

    op.execute(
        f"""
                INSERT INTO workflow_templates (filename, content, workflow_name)
                VALUES ('std_cms_imaging.sh', E'{old_content}', 'std_cms_imaging')
                """
    )
